<?php

add_action( 'customize_register' , 'gulf_theme_options' );
function gulf_theme_options( $wp_customize ) {
	global $wpdb;
	
	// THEME
	$wp_customize->add_section( 
		'gulf_style_options', 
		array(
			'title'       => __( 'Theme Style', 'gulfoil' ),
			'priority'    => 200,
			'capability'  => 'edit_theme_options',
			'description' => __('Change style settings', 'gulfoil'), 
		) 
	);
	
	$wp_customize->add_setting( 'theme_style',
		array(
			'default' => 'white',
		)
	);	
	
	$wp_customize->add_control(
		'theme_style_control', 
		array(
			'label'    => __( 'Style', 'gulfoil' ),
			'section'  => 'gulf_style_options',
			'settings' => 'theme_style',
			'type'     => 'select',
			'choices'  => array(
				'white' => 'White',
				'blue' => 'Blue',
			),
		)
	);
	
	
	
	// SHARING
	$wp_customize->add_section( 
		'gulf_sharing_options', 
		array(
			'title'       => __( 'Sharing Settings', 'gulfoil' ),
			'priority'    => 200,
			'capability'  => 'edit_theme_options',
			'description' => __('Change sharing options', 'gulfoil'), 
		) 
	);
	
	$wp_customize->add_setting( 'update_interval',
		array(
			'default' => 3*60*60, // Every three hours
		)
	);	
	
	$wp_customize->add_control(
		'update_interval_control', 
		array(
			'label'    => __( 'Update Interval', 'gulfoil' ),
			'section'  => 'gulf_sharing_options',
			'settings' => 'update_interval',
			'type'     => 'select',
			'choices'  => array(
				0  => 'Every time page loads (not recommended)',
				15*60 => '15 minutes',
				30*60 => '30 minutes',
				60*60 => '1 hour',
				3*60*60 => '3 hours',
				6*60*60 => '6 hours',
				12*60*60 => '12 hours',
				24*60*60 => '24 hours',
			),
		)
	);
	
	
	// DETAILS
	$wp_customize->add_section( 
		'gulf_company_details', 
		array(
			'title'       => __( 'Company Details', 'gulfoil' ),
			'priority'    => 200,
			'capability'  => 'edit_theme_options',
			'description' => __('Set company details', 'gulfoil'), 
		) 
	);
	
	$wp_customize->add_setting( 'company_name',
		array(
			'default' => '',
		)
	);	
	$wp_customize->add_setting( 'company_country',
		array(
			'default' => '',
		)
	);		
	
	$wp_customize->add_control(
		'company_name_control', 
		array(
			'label'    => __( 'Company Name', 'gulfoil' ),
			'section'  => 'gulf_company_details',
			'settings' => 'company_name',
			'type'     => 'text',
		)
	);	
	
	$countries = gulf_country_list();
	$wp_customize->add_control(
		'company_country_control', 
		array(
			'label'    => __( 'Country', 'gulfoil' ),
			'section'  => 'gulf_company_details',
			'settings' => 'company_country',
			'type'     => 'select',
			'choices'  => array(''=>'') + $countries,
		)
	);		
	
	
	// API Vendors
	$wp_customize->add_section( 
		'gulf_api_options', 
		array(
			'title'       => __( 'APIs', 'gulfoil' ),
			'priority'    => 200,
			'capability'  => 'edit_theme_options',
			'description' => __('Change API options', 'gulfoil'), 
		) 
	);
	
	$wp_customize->add_setting( 'maps_api',
		array(
			'default' => 'google',
		)
	);	
	
	$wp_customize->add_control(
		'maps_api_control', 
		array(
			'label'    => __( 'Maps', 'gulfoil' ),
			'section'  => 'gulf_api_options',
			'settings' => 'maps_api',
			'type'     => 'select',
			'choices'  => array(
				'google'  => 'Google',
				'googlecn'  => 'Google China',
			),
		)
	);	
	
	
	// SOCIAL
	$wp_customize->add_section( 
		'gulf_social_options', 
		array(
			'title'       => __( 'Social', 'gulfoil' ),
			'priority'    => 200,
			'capability'  => 'edit_theme_options',
			'description' => __('Change social media settings', 'gulfoil'), 
		) 
	);
	
	$wp_customize->add_setting( 'twitter',
		array(
			'default' => '',
		)
	);	
	
	$wp_customize->add_control(
		'twitter_control', 
		array(
			'label'    => __( 'Twitter', 'gulfoil' ),
			'section'  => 'gulf_social_options',
			'settings' => 'twitter',
			'type'     => 'text',
			'description' => __('Enter your twitter name. E.g. GulfOilIntl'),
		)
	);	
	
	$wp_customize->add_setting( 'facebook',
		array(
			'default' => '',
		)
	);	
	
	$wp_customize->add_control(
		'facebook_control', 
		array(
			'label'    => __( 'Facebook', 'gulfoil' ),
			'section'  => 'gulf_social_options',
			'settings' => 'facebook',
			'type'     => 'text',
			'description' => __('Enter your full Facebook url. E.g. https://www.facebook.com/gulfoilinternational'),
		)
	);		
	
	$wp_customize->add_setting( 'youtube',
		array(
			'default' => '',
		)
	);	
	
	$wp_customize->add_control(
		'youtube_control', 
		array(
			'label'    => __( 'YouTube', 'gulfoil' ),
			'section'  => 'gulf_social_options',
			'settings' => 'youtube',
			'type'     => 'text',
			'description' => __('Enter your or a specific video YouTube url'),
		)
	);		
		
	
	// CONTENT
	$wp_customize->add_section( 
		'gulf_content_options', 
		array(
			'title'       => __( 'Content', 'gulfoil' ),
			'priority'    => 200,
			'capability'  => 'edit_theme_options',
			'description' => __('Change content options', 'gulfoil'), 
		) 
	);
	
	$wp_customize->add_setting( 'distributors',
		array(
			'default' => false,
		)
	);	
	$wp_customize->add_setting( 'distributors_default',
		array(
			'default' => 'All',
		)
	);	
	
	$wp_customize->add_control(
		'distributors_control', 
		array(
			'label'    => __( 'Distributors', 'gulfoil' ),
			'section'  => 'gulf_content_options',
			'settings' => 'distributors',
			'type'     => 'checkbox',
			'description' => __('Manage a list of local distributors'),
		)
	);	

	$services = maybe_unserialize($wpdb->get_var('SELECT post_content FROM '.$wpdb->posts.' WHERE post_type="acf-field" AND post_excerpt="services"'));
	if (isset($services['choices'])) {
		$distributorDefaultOptions = array('All'=>'All') + $services['choices'];
		$wp_customize->add_control(
			'distributors_control_default', 
			array(
				'label'    => __( 'Initial selection', 'gulfoil' ),
				'section'  => 'gulf_content_options',
				'settings' => 'distributors_default',
				'type'     => 'select',
				'choices'  => $distributorDefaultOptions,
				'description' => __('Which distributor group to show by default'),
			)
		);		
	}
	
	$wp_customize->add_setting( 'products',
		array(
			'default' => true,
		)
	);	
	
	$wp_customize->add_control(
		'products_control', 
		array(
			'label'    => __( 'Products', 'gulfoil' ),
			'section'  => 'gulf_content_options',
			'settings' => 'products',
			'type'     => 'checkbox',
			'description' => __('Manage list of available products'),
		)
	);		
	
	$wp_customize->add_setting( 'posttemplate',
		array(
			'default' => 'template-sidebar-left.php',
		)
	);	

	$templates = function_exists('get_page_templates')? get_page_templates() : wp_get_theme()->get_page_templates();
	$wp_customize->add_control(
		'posttemplate_control', 
		array(
			'label'    => __( 'Default Posts template', 'gulfoil' ),
			'section'  => 'gulf_content_options',
			'settings' => 'posttemplate',
			'type'     => 'select',
			'choices'  => array_flip($templates),
		)
	);			
	
	
}