<?php

function gulf_get_display_object() {
	global $wp_query;
	
	$object = false;

	if ($wp_query->is_home || $wp_query->is_singular) {
		if ($wp_query->is_home) {
			$post = get_post(get_option( 'page_for_posts' ));
		} else {
			global $post;
		}		
		if ($post) {
			$object = new PostType($post);
		}
		
	} elseif ($wp_query->is_tax || $wp_query->is_category) {
		$object = new TermType($wp_query->queried_object);

	}
	
	return $object;
}



add_action( 'pre_get_posts', 'gulf_fetch_translation' );
function gulf_fetch_translation( $query ) {
    if ( $query->is_main_query()) {
		if ($query->is_singular ) {
			if ($query->queried_object_id) {
				$translation = gulf_get_translation($query->queried_object_id);
				if (!empty($translation)) {
					$query->set( 'pagename', '' );
					$query->set( 'p', $translation->ID);
					$query->set( 'post_type', 'translation');
				}
			} else {
				$translation = gulf_get_translation($query->query_vars['page_id']);		
				if (!empty($translation)) {
					$query->set( 'p', $translation->ID);
					$query->set( 'page_id', $translation->ID);
					$query->set( 'post_type', 'translation');
				}
			}

		}
    }
}

add_filter('posts_results','gulf_adjust_translation_parent',10,1);
function gulf_adjust_translation_parent( $posts ) {
	foreach ($posts as $i => $post) {
		if ($post->post_type == 'translation') {
			$posts[$i]->translation_parent = $post->post_parent;
			$posts[$i]->post_parent = wp_get_post_parent_id($post->post_parent);
		}
	}
	return $posts;
}

add_action('post_action_gulf_translate','gulf_post_translate',10,1);
function gulf_post_translate($post_id) {
	$translation = gulf_get_translation($post_id);

	if (empty($translation)) {
		$translation_id = gulf_translate_post($post_id);
	} else {
		$translation_id = $translation->ID;
	}
	
	wp_redirect(admin_url('post.php?post='.$translation_id.'&action=edit'));
	exit();
}


add_action('post_action_gulf_take_ownership','gulf_post_take_ownership',10,1);
function gulf_post_take_ownership($post_id) {
	$translation = gulf_get_translation($post_id);

	if (empty($translation)) {
		// Remove sharing
		update_post_meta($post_id, 'gulf_sharing_share', 'owned');
	} else {
		global $wpdb;
		// Update post with translation's content
		$data = array('post_content'=>$translation->post_content,'post_title'=>$translation->post_title,'post_excerpt'=>$translation->post_excerpt,'post_name'=>$translation->post_name);
		$wpdb->update($wpdb->posts,$data,array('ID'=>$post_id));
		// Remove post meta
		$wpdb->delete($wpdb->postmeta,array('post_id'=>$post_id));
		// Move translation meta to post
		$wpdb->update($wpdb->postmeta,array('post_id'=>$post_id),array('post_id'=>$translation->ID));
		// Delete translation
		$wpdb->delete($wpdb->posts,array('ID'=>$translation->ID));
	}

	wp_redirect(admin_url('post.php?post='.$post_id.'&action=edit'));
	exit();
}


function gulf_get_translation($post_id) {
	global $wpdb;
	return $wpdb->get_row($wpdb->prepare("SELECT * FROM $wpdb->posts WHERE post_type=%s AND post_parent=%d AND post_status!=%s",'translation',$post_id,'trash'));
}


function gulf_translate_post($post) {
	global $wpdb;

	if (!is_object($post)) {
		$post = get_post($post);
	}
	
	$current_user = wp_get_current_user();
	$new_post_author = $current_user->ID;
	
	/*
	 * if post data exists, create the post duplicate
	 */
	if (isset($post) && $post != null) {

		/*
		 * new post data array
		 */
		$args = array(
			'comment_status' => $post->comment_status,
			'ping_status' => $post->ping_status,
			'post_author' => $new_post_author,
			'post_content' => $post->post_content,
			'post_excerpt' => $post->post_excerpt,
			'post_name' => $post->post_name,
			'post_parent' => $post->ID,
			'post_password' => $post->post_password,
			'post_status' => $post->post_type,
			'post_title' => $post->post_title,
			'post_type' => 'translation',
			'to_ping' => $post->to_ping,
			'menu_order' => $post->menu_order
		);

		/*
		 * insert the post by wp_insert_post() function
		 */
		$new_post_id = wp_insert_post($args);

		/*
		 * get all current post terms ad set them to the new post draft
		 */
		$taxonomies = get_object_taxonomies($post->post_type); // returns array of taxonomy names for post type, ex array("category", "post_tag");
		foreach ($taxonomies as $taxonomy) {
			$post_terms = wp_get_object_terms($post->ID, $taxonomy, array('fields' => 'slugs'));
			wp_set_object_terms($new_post_id, $post_terms, $taxonomy, false);
		}

		/*
		 * duplicate all post meta just in two SQL queries
		 */
		$post_meta_infos = $wpdb->get_results("SELECT meta_key, meta_value FROM $wpdb->postmeta WHERE post_id=$post->ID AND meta_key NOT LIKE 'gulf_sharing%'");
		if (count($post_meta_infos) != 0) {
			$sql_query = "INSERT INTO $wpdb->postmeta (post_id, meta_key, meta_value) ";
			foreach ($post_meta_infos as $meta_info) {
				$meta_key = $meta_info->meta_key;
				$meta_value = addslashes($meta_info->meta_value);
				$sql_query_sel[] = "SELECT $new_post_id, '$meta_key', '$meta_value'";
			}
			$sql_query.= implode(" UNION ALL ", $sql_query_sel);
			$wpdb->query($sql_query);
		}


		/*
		 * finally, redirect to the edit post screen for the new draft
		 */
		return $new_post_id;
		
	} else {
		wp_die('Post creation failed, could not find original post: ' . $post_id);
	}
}


add_action( 'init', 'gulf_translate_statuses' );
function gulf_translate_statuses(){
	global $sharedposttypes;
	foreach ($sharedposttypes as $sharedposttype) {
		$label = __(ucfirst($sharedposttype));
		register_post_status( $sharedposttype, array(
			'label'                     => $label,
			'public'                    => true,
			'exclude_from_search'       => true,
			'show_in_admin_all_list'    => true,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( $label.' <span class="count">(%s)</span>', $label.' <span class="count">(%s)</span>' ),
		) );
	}
}

add_action( 'admin_menu', 'gulf_translate_remove_publish_box' );
function gulf_translate_remove_publish_box() {
    remove_meta_box( 'submitdiv', 'translation', 'side' );
}

add_action( 'add_meta_boxes', 'gulf_translate_save_box' );
function gulf_translate_save_box() {
	global $sharedposttypes;
    add_meta_box( 'gulf-translate-save', 'Save', 'gulf_translate_save_box_cb', 'translation', 'side', 'high' );
}

function gulf_translate_save_box_cb($post) {
	?>
		<input name="original_publish" type="hidden" id="original_publish" value="<?php esc_attr_e('Update') ?>" />
		<input name="save" type="submit" class="button button-primary button-large" id="publish" value="<?php esc_attr_e( 'Update' ) ?>" />
	<?php
}


add_action( 'admin_enqueue_scripts', 'gulf_translate_enqueue_scripts' );
function gulf_translate_enqueue_scripts() {
    if ( 'translation' == get_post_type() )
        wp_dequeue_script( 'autosave' );
}


add_filter( 'the_title', 'gulf_translate_title', 10, 2 );
function gulf_translate_title( $title, $id=null ) {
	if ($id) {
		$translation = gulf_get_translation($id);
		if ($translation) {
			$title = $translation->post_title;
		}
	}
	
    return $title;
}